import 'dart:async';

import 'package:flutter/material.dart';
import 'invoke_button.dart';
import 'appgain.dart';

import 'package:appgain_io_example/text_field_alert_dialog.dart';
import 'package:flutter/services.dart';

class HomeScreen extends StatefulWidget {
  const HomeScreen({Key? key}) : super(key: key);

  @override
  _HomeScreenState createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  String _platformVersion = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
    Future(initUser);

    //  Timer.run(initUser);
  }

  Future<void> initPlatformState() async {
    String platformVersion;
    try {
      platformVersion =
          await Appgain.platformVersion ?? 'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  initUser() {
    TextFieldAlertDialog().initSDKDialog(context);
  }

  Future fireAutomator() async {
    TextFieldAlertDialog().fireTriggerPointDialog(context);
  }

  Future fireAutomatorWithPersonalization() async {
    TextFieldAlertDialog().fireAutomatorWithPersonalizationDialog(context);
  }

  Future cancelFireAutomator() async {
    TextFieldAlertDialog().cancelFireTriggerPointDialog(context);
  }

  Future addPurchase() async {
    TextFieldAlertDialog().logPurchaseDialog(context);
  }

  Future updateUserId() async {
    TextFieldAlertDialog().updateUserIdDialog(context);
  }

  Future updateUser() async {
    TextFieldAlertDialog().updateUserDialog(context);
  }

  Future addEmailChannel() async {
    TextFieldAlertDialog().emailNotificationChannelDialog(context);
  }

  Future addSMSChannel() async {
    TextFieldAlertDialog().smsNotificationChannelDialog(context);
  }

  Future logEvent() async {
    TextFieldAlertDialog().logEventDialog(context);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Appgain SDK Plugin'),
      ),
      body: SingleChildScrollView(
          child: Center(
        child: Column(children: [
          const SizedBox(height: 10),
          InvokeButton(
              buttonName: 'INITIALIZE',
              function: () => TextFieldAlertDialog().initSDKDialog(context)),
          InvokeButton(
              buttonName: 'GET USER ID', function: () => Appgain().getUserId()),
          InvokeButton(
              buttonName: 'MATCH LINK', function: () => Appgain().matchLink()),
          InvokeButton(
              buttonName: 'FIRE AUTOMATOR', function: () => fireAutomator()),
          InvokeButton(
              buttonName: 'FIRE AUTOMATOR WITH PERSONALIZATION',
              function: () => fireAutomatorWithPersonalization()),
          InvokeButton(
              buttonName: 'CANCEL AUTOMATOR',
              function: () => cancelFireAutomator()),
          InvokeButton(
              buttonName: 'ADD PURCHASE', function: () => addPurchase()),
          InvokeButton(
              buttonName: "UPDATE USER ID", function: () => updateUserId()),
          InvokeButton(
              buttonName: 'UPDATE USER DATA', function: () => updateUser()),
          InvokeButton(
              buttonName: 'ADD EMAIL CHANNEL',
              function: () => addEmailChannel()),
          InvokeButton(
              buttonName: 'ADD SMS CHANNEL', function: () => addSMSChannel()),
          InvokeButton(buttonName: 'LOG EVENT', function: () => logEvent()),
          Text(_platformVersion)
        ]),
      )),
    );
  }
}
